import { NetlifyExtensionClient, type NetlifyExtensionClientConstructorParams } from "./extension_api_client.js";
import type { NetlifyClient } from "./netlify_api_client.js";
/**
 * ## Usage example
 *
 * This example shows a build event handler that uses the available `ACCOUNT_ID` and `SITE_ID` constants to do a call using the `client` to fetch a site's config.
 * This config can hold useful information for the extension, such as an extension's state, specific configurations on how the extension should function, or keys that can be used to interact with third-party APIs.
 *
 * ```tsx
 * // src/index.ts
 * import { NetlifyExtension } from '@netlify/sdk';
 *
 * const extension = new NetlifyExtension();
 *
 * extension.addBuildEventHandler('onPreBuild', async ({ client, constants }) => {
 *   const { ACCOUNT_ID, SITE_ID } = constants;
 *   const siteConfig = client.getSiteConfiguration(ACCOUNT_ID, SITE_ID);
 *
 *   // do something with the site configuration
 * });
 *
 * export { extension };
 * ```
 *
 * @link NetlifyExtensionClient
 */
export declare class NetlifyExtensionBuildClient<SiteConfiguration, TeamConfiguration, ConnectorConfiguration> {
    private client;
    constructor(...params: NetlifyExtensionClientConstructorParams);
    /**
     * @link NetlifyExtensionClient.getTeamConfiguration
     */
    getTeamConfiguration: NetlifyExtensionClient<unknown, TeamConfiguration, unknown>["getTeamConfiguration"];
    /**
     * @link NetlifyExtensionClient.getSiteConfiguration
     */
    getSiteConfiguration: NetlifyExtensionClient<SiteConfiguration, unknown, unknown>["getSiteConfiguration"];
    /**
     * @link NetlifyClient.getSite
     */
    getSite: (typeof NetlifyClient.prototype)["getSite"];
    /**
     * @link NetlifyClient.getAccount
     */
    getAccount: (typeof NetlifyClient.prototype)["getAccount"];
}
//# sourceMappingURL=extension_api_build_client.d.ts.map